---
title: "CSA CCM v4"
description: "Terraform compliance scanning for CSA CCM v4 — assess for free, remediate with ComplyForm"
---

import { Badge } from '@astrojs/starlight/components';

<Badge text="Team" variant="caution" />
<Badge text="Benchmark" variant="tip" />

**Issuing body:** [CSA](https://cloudsecurityalliance.org)
**Jurisdiction:** Global — Global
**Countries:** Worldwide


## Assessment

Assess your infrastructure against CSA CCM for free at any tier:

```bash
complyform assess --frameworks=csa_ccm
```

## Remediation

Requires Team tier or higher ($1,999/yr) for remediation.

```bash
complyform remediate --frameworks=csa_ccm
```

## Related Frameworks

- [SOC 2 Type II](/frameworks/soc2)
- [CIS GCP v2.0](/frameworks/cis_gcp)
- [CIS Azure v2.0](/frameworks/cis_azure)
- [CIS AWS v3.0](/frameworks/cis_aws)
